import * as cdk from "aws-cdk-lib";
import { Construct } from "constructs";
//import { Repository } from "aws-cdk-lib/aws-codecommit";

import { App } from "aws-cdk-lib";
import { Cloud9Environment, Cloud9AmiType, Cloud9ConnectionType } from "bootstrappable-cloud9";

export class Cloud9EnvironmentExampleStack extends cdk.Stack {
  constructor(scope: Construct, id: string, props?: cdk.StackProps) {
    super(scope, id, props);

    //-----------------------------------------------------
    //-                Instantiation                      -
    //-----------------------------------------------------
    const environment = new Cloud9Environment(this, "environment", {
      name: "example-environment",
      description: "An example environment",
      imageId: Cloud9AmiType.AMZN_LINUX_2,
      connectionType: Cloud9ConnectionType.SSM,
    });

    //-----------------------------------------------------
    //-               Access Management                   -
    //-----------------------------------------------------
    // Environment owner is CloudFormation's role by default (if not specified)
    environment.grantCollaboratorAccess(
      "arn:aws:sts::249522321342:assumed-role/Admin/rafams-Isengard"
    );

    //-----------------------------------------------------
    //-                Bootstrapping                      -
    //-----------------------------------------------------
    // Existing CodeCommit Repository (alternatively create new)
    // const repository = Repository.fromRepositoryName(this, "test", "test-repo");
    // environment.cloneCodeCommitRepo(repository, "test");
    environment.cloneGitRepo("https://github.com/aws-samples/aws-copilot-pubsub", "copilot");
    environment.addInitCommands(["sudo yum update -y", "sudo yum install -y jq"]);
    environment.resizeEbsVolumeTo(100);

    //-----------------------------------------------------
    //-                  Outputs                         -
    //-----------------------------------------------------
    new cdk.CfnOutput(this, "environmentUrl", {
      value: environment.environmentUrl,
      description: "The URL of the environment",
    });
  }
}

const app = new App();
new Cloud9EnvironmentExampleStack(app, "Cloud9Environment", {});
app.synth();
